Executor class
Methods
execute (List <String > arguments , {bool runInShell = true , bool checkIfRunning = true , Duration ? timeout , bool debug = false })
→ Future <ProcessResult >
executeToFile (List <String > arguments , {required String outputFile , bool runInShell = true , bool checkIfRunning = true , Duration ? timeout , bool debug = false })
→ Future <int >
Executes an adb command and redirects the raw (binary) stdout of the
process to a file on the host, mimicking a shell redirection like
adb ... exec-out screencap -p > file.png.
init ()
→ Future <void >
isRooted (List <String > arguments , {bool debug = false })
→ Future <bool >
killServer ({bool debug = false })
→ Future <void >
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
root (List <String > arguments , {bool debug = false })
→ Future <void >
start (List <String > arguments , {bool runInShell = true })
→ Future <Process >
startServer ({bool debug = false })
→ Future <void >
toString ()
→ String
A string representation of this object.
inherited
unroot (List <String > arguments , {bool debug = false })
→ Future <void >
flutter_android_bridge 0.3.0