push method

Future<void> push({
  1. required String src,
  2. required String dst,
  3. bool debug = false,
})

Pushes a file from the host to the device.

src is the path to the file on the device. dst is the path to the file on the host.

Implementation

Future<void> push({
  required String src,
  required String dst,
  bool debug = false,
}) {
  return _bridge.executor.execute([
    ..._connection.arguments,
    'push',
    src,
    dst,
  ], debug: debug);
}