stop method
Stops the mirror: closes any recording (flushing the file), kills the
adb screenrecord process, drops the player connection and closes the
server socket. Safe to call multiple times.
Implementation
Future<void> stop() => _stop();
Stops the mirror: closes any recording (flushing the file), kills the
adb screenrecord process, drops the player connection and closes the
server socket. Safe to call multiple times.
Future<void> stop() => _stop();