stop method

Future<void> stop()

Kills the adb process and completes done. Safe to call more than once, and safe to call after the session already ended on its own.

Implementation

Future<void> stop() async {
  if (_stopped) return;
  _process.kill();
  await _finish('stop() called');
}