pull method
Pulls a file from the device to the host.
src is the path to the file on the device.
dst is the path to the file on the host.
Implementation
Future<void> pull({
required String src,
required String dst,
bool debug = false,
}) {
return _bridge.executor.execute([
..._connection.arguments,
'pull',
src,
dst,
], debug: debug);
}