pid property
int
get
pid
The pid of the host adb process. The device-side command is a child
of the adbd shell service and goes away with it, so killing this one is
enough to stop the sampling on the device too.
Implementation
int get pid => _process.pid;